# slotpy:
## Slide and plot with python

You want to know how the parameters in your large datasets evolve?

Simply click and watch! 

![alt text](https://github.com/Chia-vie/slotpy/blob/main/slotpy_logo_prelim.png)



